## Want to Contribute?

Found an issue? Thank you for helping out by reporting it. Please describe the
problem, what you tried, what you expected to see, and what you actually
experienced. Please [re-read the documentation](http://timeago.yarp.com/) to
make sure you're using the API as designed, but if you found something that's
broken, we really appreciate your efforts in letting us know. Bonus points for
submitting a failing test case to help us diagnose and potentially fix the
issue.

## Want to Contribute?

Awesome. We love help, but before getting started, please read:

**[Don't "Push" Your Pull Requests](http://www.igvita.com/2011/12/19/dont-push-your-pull-requests/)**

## Ready for a Pull-Request?

1. Fork the repo.

2. Run the tests. Run `rake` or open `open test/index.html`. We only take pull
   requests with passing tests, and it's great to know that you started from a
   clean slate.

3. Add a test for your change. Only refactoring and documentation change
  require no new tests. If you are adding functionality or fixing a bug, we
  need a test!

4. Make the test pass.

5. Push to your fork (hopefully this comes from a topical branch) and submit a
   pull request.

At this point you're waiting on us. Please keep in mind that OSS maintainers
are often very busy. We'll do our best to at least comment on issues and
pull-requests as soon as possible, but sometimes life gets in the way.  We may
also suggest some changes or improvements or alternatives.
